==> SQLExchange 1.0.3.2.zip: SQLExchange 1.0.3.2/SQLEClient/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by SQLEClient.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDS_REGISTRYKEY                 4
#define IDS_STRING5                     5
#define IDI_MAINICON                    101
#define IDI_MAIN                        101
#define IDD_MAIN                        102
#define IDI_ICON1                       103
#define IDI_SCHEDTAB                    103
#define IDD_SECURITYTAB                 104
#define IDD_ADVANCEDTAB                 105
#define IDI_ADVANCEDTAB                 106
#define IDD_REPLICATION                 106
#define IDD_GENERALTAB                  107
#define IDI_GENERALTAB                  107
#define IDI_SECURITYTAB                 108
#define IDR_MAINMENU                    133
#define IDB_SPLASH                      134
#define IDD_SPLASH                      135
#define IDD_SQLTAB                      136
#define IDI_SQLTAB                      136
#define IDD_SCHEDTAB                    137
#define TDI_TRAYICON                    138
#define IDI_TRAYICON                    138
#define IDD_REPISSUES                   138
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_LOGLIST                     1004
#define IDC_RECVLIST                    1005
#define IDC_DATETIMEPICKER1             1006
#define IDC_COMPANYPWD                  1007
#define IDC_TALBES                      1007
#define IDC_TCPLOOPDELAY                1008
#define ID_OK                           1008
#define IDC_COMPANYNAME                 1009
#define ID_CANCEL                       1009
#define IDC_PORTALSVR                   1010
#define IDC_SERVERADDRESS               1010
#define ID_CKHALL                       1010
#define ID_CHKALL                       1010
#define IDC_PORTALSVRPORT               1011
#define IDC_SERVERPORT                  1011
#define ID_CHKNONE                      1011
#define ID_CLOSE                        1012
#define ID_CANCEL2                      1012
#define ID_REPISSUES                    1012
#define IDC_AUTHSTRING                  1018
#define IDC_BASECOMMKEY                 1019
#define IDC_AUTHKEY                     1019
#define IDC_LOCALCRYPTKEY               1020
#define IDC_ADMINPASSWORD1              1021
#define IDC_ADMINPASSWORD2              1022
#define IDC_SPLASHPROGRESS              1023
#define IDC_SERVER                      1024
#define IDC_SQLDRIVER                   1025
#define IDC_SQLDATABASE                 1026
#define IDC_SQLUSERNAME                 1027
#define IDC_SQLPASSWORD                 1028
#define IDC_CONNECTINTERVAL             1029
#define IDC_VERSIONTAG                  1030
#define ID_HELP_ABOUT                   40001
#define ID_SETTINGS_REPLICATION         40002
#define ID_SETTINGS_GENERATEREPLICATIONSQL 40003
#define ID_CONNECTION_CONNECTNOW        40012
#define ID_CONNECTION_FORCEDISCONNECT   40013
#define ID_SETTINGS_GENERALSETTINGS     40014
#define ID_ADVANCED_DEBUGMODE           40016
#define ID_ADVANCED_OPENCONSOLE         40017
#define ID_ADVANCED_FLUSHVARIABLES      40018

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        107
#define _APS_NEXT_COMMAND_VALUE         40004
#define _APS_NEXT_CONTROL_VALUE         1013
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> SQLExchange 1.0.3.4.zip: SQLExchange 1.0.3.4/SQLEClient/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by SQLEClient.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDS_REGISTRYKEY                 4
#define IDS_STRING5                     5
#define IDI_MAINICON                    101
#define IDI_MAIN                        101
#define IDD_MAIN                        102
#define IDI_ICON1                       103
#define IDI_SCHEDTAB                    103
#define IDD_SECURITYTAB                 104
#define IDD_ADVANCEDTAB                 105
#define IDI_ADVANCEDTAB                 106
#define IDD_REPLICATION                 106
#define IDD_GENERALTAB                  107
#define IDI_GENERALTAB                  107
#define IDI_SECURITYTAB                 108
#define IDI_ICON2                       109
#define IDI_AVAILFORREP                 109
#define IDI_ICON3                       110
#define IDI_NOTAVAILFORREP              110
#define IDI_ICON4                       111
#define IDI_REPLICATING                 111
#define IDR_MAINMENU                    133
#define IDB_SPLASH                      134
#define IDD_SPLASH                      135
#define IDD_SQLTAB                      136
#define IDI_SQLTAB                      136
#define IDD_SCHEDTAB                    137
#define TDI_TRAYICON                    138
#define IDI_TRAYICON                    138
#define IDD_REPISSUES                   138
#define IDD_STATUSDLG                   141
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_LOGLIST                     1004
#define IDC_RECVLIST                    1005
#define IDC_DATETIMEPICKER1             1006
#define IDC_COMPANYPWD                  1007
#define IDC_TALBES                      1007
#define IDC_TCPLOOPDELAY                1008
#define ID_OK                           1008
#define ID_APPLY                        1008
#define IDC_COMPANYNAME                 1009
#define ID_CANCEL                       1009
#define IDC_PORTALSVR                   1010
#define IDC_SERVERADDRESS               1010
#define ID_CKHALL                       1010
#define ID_CHKALL                       1010
#define IDC_PORTALSVRPORT               1011
#define IDC_SERVERPORT                  1011
#define ID_CHKNONE                      1011
#define IDC_STATTEXT                    1011
#define ID_CLOSE                        1012
#define ID_CANCEL2                      1012
#define ID_REPISSUES                    1012
#define IDC_STATPROGRESS                1012
#define IDC_AUTHSTRING                  1018
#define IDC_BASECOMMKEY                 1019
#define IDC_AUTHKEY                     1019
#define IDC_LOCALCRYPTKEY               1020
#define IDC_ADMINPASSWORD1              1021
#define IDC_ADMINPASSWORD2              1022
#define IDC_SPLASHPROGRESS              1023
#define IDC_SERVER                      1024
#define IDC_SQLDRIVER                   1025
#define IDC_SQLDATABASE                 1026
#define IDC_SQLUSERNAME                 1027
#define IDC_SQLPASSWORD                 1028
#define IDC_CONNECTINTERVAL             1029
#define IDC_VERSIONTAG                  1030
#define ID_TIMEWINDBEGIN                4000
#define ID_TIMEWINDEND                  4001
#define ID_HELP_ABOUT                   40001
#define ID_SETTINGS_REPLICATION         40002
#define ID_SETTINGS_GENERATEREPLICATIONSQL 40003
#define ID_CONNECTION_CONNECTNOW        40012
#define ID_CONNECTION_FORCEDISCONNECT   40013
#define ID_SETTINGS_GENERALSETTINGS     40014
#define ID_ADVANCED_DEBUGMODE           40016
#define ID_ADVANCED_OPENCONSOLE         40017
#define ID_ADVANCED_FLUSHVARIABLES      40018

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        112
#define _APS_NEXT_COMMAND_VALUE         40004
#define _APS_NEXT_CONTROL_VALUE         1013
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
